@@ -16,6 +16,7 @@ from .nav import Nav
 from .searchbox import SearchBox
 from .slider import Slider
 from .spinbutton import SpinButton
+from .spinner import Spinner
 from .tabs import Tabs, Tab
 from .dialog import Dialog
 from .grid import Grid, Columns, Items, Column, Item
@@ -27,4 +28,5 @@ from .callout import Callout
 from .image import Image
 from .linechart import LineChart
 from .piechart import PieChart
+from .datepicker import DatePicker
 from .pglet import *
\ No newline at end of file
