@@ -4,7 +4,7 @@ from .control import Control
 class SearchBox(Control):
     def __init__(self, id=None, value=None, placeholder=None, underlined=None,
             icon=None, icon_color=None, data=None, on_search=None,
-            on_clear=None, on_escape=None, on_change=None,
+            on_clear=None, on_change=None,
             width=None, height=None, padding=None, margin=None,
             visible=None, disabled=None):
 
@@ -19,7 +19,6 @@ class SearchBox(Control):
         self.icon_color = icon_color
         self.on_search = on_search
         self.on_clear = on_clear
-        self.on_escape = on_escape
         self.on_change = on_change
 
     def _get_control_name(self):
@@ -43,15 +42,6 @@ class SearchBox(Control):
     def on_clear(self, handler):
         self._add_event_handler("clear", handler)
 
-# on_escape
-    @property
-    def on_escape(self):
-        return self._get_event_handler("escape")
-
-    @on_escape.setter
-    def on_escape(self, handler):
-        self._add_event_handler("escape", handler)
-
 # on_change
     @property
     def on_change(self):
@@ -61,9 +51,9 @@ class SearchBox(Control):
     def on_change(self, handler):
         self._add_event_handler("change", handler)
         if handler != None:
-            self._set_attr("on_change", True)
+            self._set_attr("onchange", True)
         else:
-            self._set_attr("on_change", False)
+            self._set_attr("onchange", False)
 
 # value
     @property
