@@ -1,8 +1,8 @@
 from .utils import encode_attr
 from .control import Control
 
-# P
-class P(Control):
+# Point
+class Point(Control):
     def __init__(self, id=None, x=None, y=None, legend=None, color=None,
         x_tooltip=None, y_tooltip=None):
         Control.__init__(self, id=id)
@@ -108,7 +108,7 @@ class VerticalBarChart(Control):
             visible=visible, disabled=disabled)
 
         self.__data = Data(points=points)
-        self.ledend = legend
+        self.legend = legend
         self.tooltips = tooltips
         self.bar_width = bar_width
         self.colors = colors
